@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+from dyatel.base.element import Element
 from dyatel.dyatel_play.play_element import PlayElement
 from dyatel.dyatel_play.play_utils import get_selenium_completable_locator
 from dyatel.mixins.internal_utils import get_child_elements, initialize_objects_with_args
@@ -9,7 +10,7 @@ from dyatel.mixins.log_mixin import LogMixin
 
 class PlayPage(DriverMixin, LogMixin):
 
-    def __init__(self, locator: str, locator_type='', name=''):
+    def __init__(self, locator: str, locator_type: str, name: str):
         """
         Initializing of web page with playwright driver
 
@@ -21,7 +22,7 @@ class PlayPage(DriverMixin, LogMixin):
 
         self.locator = get_selenium_completable_locator(locator)
         self.name = name if name else self.locator
-        self.locator_type = f'{locator_type}: locator_type does not supported for playwright'
+        self.locator_type = f'{locator_type} - locator_type does not supported for playwright'
 
         self.url = getattr(self, 'url', '')
         self.page_elements = get_child_elements(self, PlayElement)
@@ -34,6 +35,6 @@ class PlayPage(DriverMixin, LogMixin):
 
         :return: PlayElement object
         """
-        anchor = PlayElement(locator=self.locator, locator_type=self.locator_type, name=self.name)
+        anchor = Element(locator=self.locator, locator_type='', name=self.name)
         anchor._driver_instance = self.driver_wrapper
         return anchor
