@@ -1,4 +1,4 @@
-from dyatel.internal_utils import all_tags
+from dyatel.mixins.internal_utils import all_tags
 
 
 def get_selenium_completable_locator(locator):
@@ -15,5 +15,7 @@ def get_selenium_completable_locator(locator):
         return locator
     elif '.' in locator and not brackets:
         return locator
+    elif '#' in locator:
+        return locator
     else:
         return f'id={locator}'
