@@ -4,12 +4,11 @@ import time
 from typing import Union
 
 from dyatel.dyatel_sel.core.core_page import CorePage
-from dyatel.dyatel_sel.sel_utils import get_locator_type
 
 
 class MobilePage(CorePage):
 
-    def __init__(self, locator: str, locator_type='', name=''):
+    def __init__(self, locator: str, locator_type: str, name: str):
         """
         Initializing of mobile page with appium driver
 
@@ -17,7 +16,6 @@ class MobilePage(CorePage):
         :param locator_type: specific locator type
         :param name: name of page (will be attached to logs)
         """
-        self.locator_type = locator_type if locator_type else get_locator_type(locator)
         super().__init__(locator=locator, locator_type=locator_type, name=name)
 
     def swipe(self, start_x: int, start_y: int, end_x: int, end_y: int,
